\name{aggregate.zoo}
\alias{aggregate.zoo}
\title{Compute Summary Statistics of zoo Objects}
\description{
Splits a zoo object into subsets along a coarser index grid,
computes summary statistics for each, and returns the 
reduced zoo object.
}

\usage{
\method{aggregate}{zoo}(x, by, FUN, \dots)
}

\arguments{
  \item{x}{an object of class \code{"zoo"}.}
  \item{by}{index vector the same length as \code{index(x)} which defines
    aggregation groups and the new index to be associated with each group.}
  \item{FUN}{a scalar function to compute the summary statistics
    which can be applied to all subsets.}
  \item{\dots}{further arguments passed to \code{FUN}.}
}

\value{
An object of class \code{"zoo"}.
}

\seealso{\code{\link{zoo}}}

\examples{
## averaging over values in a month:
# long series
x.date <- as.POSIXct(paste("2003-", rep(1:4, 4:1), "-", sample(1:28, 10, replace = TRUE), sep = ""))
x <- zoo(rnorm(12), x.date)
# coarser dates
x.date2 <- as.POSIXct(paste("2003-", rep(1:4, 4:1), "-1", sep = ""))
x2 <- aggregate(x, x.date2, mean)
# compare time series
plot(x)
lines(x2, col = 2)


## aggregate on month and extend to monthly time series
# test data
if(require(chron)) {
y <- zoo(matrix(11:15,nr=5,nc=2), chron(c(15,20,80,100,110)))
colnames(y) <- c("A", "B")

# aggregate by month using first of month as times for coarser series
# Uses fact that chron dates format, by default, to mm/dd/yy
firstofmonth <- function(x) chron(sub("/../", "/01/", format(x)))
y2 <- aggregate.zoo(y, firstofmonth(time(y)), tail, 1)

# fill in missing months by merging with an empty series containing
# a complete set of 1st of the months
yrt2 <- range(time(y2))
y0 <- zoo(,seq(from = yrt2[1], to = yrt2[2], by = "month"))[,-1]
merge(y2, y0)
}


## create regular series using Date class
# test data
x <- zoo(1:5, structure(c(15,20,80,100,110), class = "Date"))

# aggregate by month using first of month as times for coarser series
# Uses fact that format.Date defaults to yyyy-mm-dd
firstofmonth <- function(x) as.Date(sub("..$", "01", format(x)))
x2 <- aggregate.zoo(x, firstofmonth(time(x)), tail, 1)

# fill in missing months by merging with an empty series containing
# a complete set of 1st of the months
xrt2 <- range(time(x2))
x0 <- zoo( , seq(from = xrt2[1], to = xrt2[2], by = "month"))[,-1]
merge(x2, x0)


}
\keyword{ts}

\eof
\name{as.zoo}
\alias{as.zoo}
\alias{as.zoo.default}
\alias{as.zoo.ts}
\alias{as.zoo.irts}
\title{Coercion to zoo}
\description{
A generic function for coercing objects to class \code{"zoo"}.
}
\usage{
as.zoo(x, \dots)
}
\arguments{
  \item{x}{an object,}
  \item{\dots}{currently not used.}
}

\details{
\code{as.zoo} currently has a default method and methods
for \code{\link{ts}} and \code{\link[tseries]{irts}} objects.
}

\value{
A \code{\link{zoo}} object.
}

\seealso{\code{\link{zoo}}, \code{\link{ts}}, \code{\link[tseries]{irts}}}

\examples{
as.zoo(rnorm(5))
}
\keyword{ts}

\eof
\name{index}
\alias{index}
\alias{index}
\alias{index.default}
\alias{index.zoo}
\alias{time.zoo}
\title{Extracting Index From Objects}
\description{
\code{index} is a generic function for extracting 
the index of an object.
}
\usage{
index(x, \dots)
}
\arguments{
  \item{x}{an object,}
  \item{\dots}{currently not used.}
}

\details{
\code{index} is a generic function for extracting the index
of objects, currently it has a default method and a method
for \code{\link{zoo}} objects which is the same as the
\code{\link{time}} method for \code{\link{zoo}} objects.
}

\seealso{\code{\link{time}}, \code{\link{zoo}}}

\examples{
x.date <- as.POSIXct(paste("2003-02-", c(1, 3, 7, 9, 14), sep = ""))
x <- zoo(rnorm(5), x.date)
index(x)

x <- matrix(rnorm(10), ncol = 2)
index(x)
}
\keyword{ts}

\eof
\name{merge.zoo}
\alias{merge.zoo}
\title{Merge Two or More zoo Objects}
\description{
Merge two zoo objects by common indexes (times), or do other
versions of database "join" operations.
}

\usage{
\method{merge}{zoo}(\dots, all = TRUE, fill = NA, suffixes = NULL)
}

\arguments{
  \item{\dots}{two or more objects of class \code{"zoo"}.}
  \item{all}{logical vector of the same length as the number of \code{"zoo"}
    objects which should be merged (otherwise expanded). All indexes
    (times) of the objects corresponding to TRUE are included, for those
    corresponding to FALSE only the indexes present in all objects are
    included. For the default \code{all = TRUE} this corresponds to 
    a union of all indexes, for \code{all = FALSE} to the intersection
    of all indexes.}
  \item{fill}{an element for filling the gaps in merged \code{"zoo"}
    objects which can arise when all = TRUE and some zoo arguments have some
    index values not in all other zoo arguments.}
  \item{suffixes}{character vector of the same length as the number of
    \code{"zoo"} objects that specifies the suffixes to be used for making
    the merged column names unique.}
}

\details{
The indexes of different
\code{"zoo"} objects can be of different classes and are coerced to
one class in the resulting object (with a warning).
}

\value{
An object of class \code{"zoo"}.
}

\seealso{\code{\link{zoo}}}

\examples{
## simple merging
x.date <- as.POSIXct(paste("2003-02-", c(1, 3, 7, 9, 14), sep = ""))
x <- zoo(rnorm(5), x.date)

y1 <- zoo(matrix(1:10, ncol = 2), 1:5)
y2 <- zoo(matrix(rnorm(10), ncol = 2), 3:7)

## using arguments `fill' and `suffixes'
merge(y1, y2, all = FALSE)
merge(y1, y2, all = FALSE, suffixes = c("a", "b"))

merge(x, y1, y2, all = TRUE)
merge(x, y1, y2, all = TRUE, fill = 0)


## extend an irregular series to a regular one:
# create a constant series
z <- zoo(1, seq(4)[-2])
# create a series with zero columns
z0 <- zoo(, 1:4)[,-1]
# do the extension
merge(z, z0)
# same but with zero fill
merge(z, z0, fill = 0)
}
\keyword{ts}

\eof
\name{plot.zoo}
\alias{plot.zoo}
\alias{lines.zoo}
\title{Plotting zoo Objects}
\description{
Plotting method for objects of class \code{"zoo"}.
}
\usage{
\method{plot}{zoo}(x, plot.type = c("multiple", "single"),
  panel = lines, xlab = "Index", ylab = NULL, main = NULL,
  ylim = NULL, oma = c(6, 0, 5, 0), col = 1, lty = 1, nc,
  \dots)
\method{lines}{zoo}(x, type = "l", \dots)
}
\arguments{
  \item{x}{an object of class \code{"zoo"}.}
  \item{plot.type}{for multivariate zoo objects, should the observations
     be plotted separately (with a common index axis) or on a single plot?}
  \item{panel}{a 'function(x, y, col, lty, \dots)'  which gives the
     action to be carried out in each panel of the display for
    'plot.type="multiple"'.  The default is 'lines'.}
  \item{xlab, ylab, main, ylim, oma, type}{graphical arguments, see \code{\link{par}}.}
  \item{col, lty}{graphical arguments that can be vectorized for
     'plot.type = "multiple"'.}
  \item{nc}{the number of columns to use when 'plot.type="multiple"'.
    Defaults to 1 for up to 4 series, otherwise to 2.}
  \item{\dots}{additional graphical arguments.}
}

\details{
The methods for \code{plot} and \code{lines} are very similar
to the corresponding \code{ts} methods.
}

\seealso{\code{\link{zoo}}, \code{\link{plot.ts}}}

\examples{
x.date <- as.POSIXct(paste("2003-02-", c(1, 3, 7, 9, 14), sep = ""))
x <- zoo(rnorm(5), x.date)
x2 <- zoo(rnorm(5, sd = 0.2), x.date)
plot(x)
lines(x2, col = 2)
}
\keyword{ts}

\eof
\name{zoo}
\alias{zoo}
\alias{print.zoo}
\alias{is.zoo}
\alias{[.zoo}
\alias{str.zoo}
\alias{window.zoo}
\alias{rbind.zoo}
\title{Z's Ordered Observations}
\description{
\code{zoo} is the creator for an S3 class of indexed
totally ordered observations which includes irregular
time series.
}
\usage{
zoo(x = NA, order.by = index(x))
}
\arguments{
  \item{x}{a vector or matrix.}
  \item{order.by}{a vector by which the observations in \code{x}
    are ordered.}
}

\details{
\code{zoo} is still under development, but it provides \code{plot}
and \code{index} (or \code{time}) methods for \code{"zoo"} objects
and can convert \code{"ts"} and \code{"irts"} objects with
\code{\link{as.zoo}}.

The vector of indexes \code{order.by} can be of arbitrary class,
but it is essential that \code{order(order.by)} works. For other
functions it is assumed that \code{c()}, \code{length()},
\code{match()} and subsetting \code{[,} work.

If \code{x} is shorter or longer than \code{order.by} it is
expanded accordingly.
}

\value{
A vector or matrix with an \code{"index"} attribute of the same
dimension (\code{NROW(x)}) by which \code{x} is ordered.
}

\seealso{\code{\link{plot.zoo}}, \code{\link{index}}, \code{\link{merge.zoo}}}

\examples{
## simple creation and plotting
x.date <- as.POSIXct(paste("2003-02-", c(1, 3, 7, 9, 14), sep = ""))
x <- zoo(rnorm(5), x.date)
plot(x)
time(x)

## subsetting
x[1:3]

# create a constant series
z <- zoo(1, seq(4)[-2])

# create a series with zero columns
z0 <- zoo(, 1:4)[,-1]
}
\keyword{ts}

\eof
